
_PANDAS_FOUND = True
_PYARROW_FOUND = True
_POLARS_FOUND = True

try:
    import pandas as pd # pragma: no cover
    import numpy as np # pragma: no cover
except ImportError:
    _PANDAS_FOUND = False

try:
    import pyarrow as pa # pragma: no cover
except ImportError:
    _PYARROW_FOUND = False

try:
    import polars as pl # pragma: no cover
except ImportError:
    _POLARS_FOUND = False



from pymsd.proto.msd_pb2 import *
from pymsd.proto.msd_pb2_grpc import *
from pymsd.proto.dataframe_pb2 import *
from pymsd.proto.schema_pb2 import *



try:
    from pymsd.pandas import *
except Exception:
    pass

try:
    from pymsd.polars import * 
except Exception:
    pass

try:
    from pymsd.numpy import * 
except Exception:
    pass

try:
    from pymsd.pyarrow import * 
except Exception:
    pass

from pymsd.easy import *


import pandas as pd
import numpy as np
import pymsd.proto.dataframe_pb2 as msd


def to_pandas_series(s: msd.Series) -> pd.Series:
    """
    convert msd.Series to pandas.Series
    """
    if s.dtype == msd.FieldKind.Float64:
        a = np.frombuffer(s.datas, np.float64)
        return pd.Series(a, name=s.name)
    if s.dtype == msd.FieldKind.Int64:
        a = np.frombuffer(s.datas, np.int64)
        return pd.Series(a, name=s.name)
    if s.dtype == msd.FieldKind.DateTime:
        a = np.frombuffer(s.datas, 'datetime64[ns]')
        a = a + 8 * 3600 * 1_000_000_000
        return pd.Series(a, name=s.name)
    if s.dtype == msd.FieldKind.Decimal64:
        a = np.frombuffer(s.datas, '>i8')
        v = a >> 8
        d = 10**((a & 0xFF) >> 4)
        neg = np.where(a & 1 == 1, -1, 1)
        return pd.Series(v * neg / d, dtype=np.float64, name=s.name)
    if s.dtype == msd.FieldKind.String:
        return pd.Series(s.texts, dtype=str, name=s.name)
    return None


def to_pandas_dataframe(df: msd.DataFrame) -> pd.DataFrame:
    """
    convert msd.DataFrame to pandas.DataFrame
    """
    data = {}
    index = None
    for i, c in enumerate(df.columns):
        if i != df.pk_col:
            data[c.name] = to_pandas_series(c)
        else:
            index = to_pandas_series(c)
    return pd.DataFrame.from_dict(data).set_index(index)



import pymsd.proto.dataframe_pb2 as msd

_NUMPY_FOUND = True
_PYARROW_FOUND = True
_POLARS_FOUND = True

try:
    import numpy as np # pragma: no cover
except ImportError:
    _PANDAS_FOUND = False

try:
    import pyarrow as pa # pragma: no cover
except ImportError:
    _PYARROW_FOUND = False

try:
    import polars as pl # pragma: no cover
except ImportError:
    _POLARS_FOUND = False

def to_polars_series(s: msd.Series) -> pl.Series:
    pass

def to_polars_dataframe(df: msd.DataFrame) -> pl.DataFrame:
    """
    convert msd.DataFrame to pandas.DataFrame
    """
    C = None
    if _PYARROW_FOUND:
        import pymsd.pyarrow
        C = pymsd.pyarrow.to_arrow_array
    elif _NUMPY_FOUND:
        import pymsd.numpy
        C = pymsd.numpy.to_numpy_ndarray
    else:
        C = to_polars_series

    data = {}
    for _i, c in enumerate(df.columns):
        data[c.name] = C(c)
    return pl.DataFrame(data)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pymsd/proto/dataframe.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bpymsd/proto/dataframe.proto\x12\tdataframe\"Y\n\x06Series\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05\x64type\x18\x02 \x01(\x0e\x32\x14.dataframe.FieldKind\x12\r\n\x05\x64\x61tas\x18\x0f \x01(\x0c\x12\r\n\x05texts\x18\x10 \x03(\t\"k\n\tDataFrame\x12\x0e\n\x06pk_col\x18\x01 \x01(\x05\x12\x19\n\x0c\x64istinct_col\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\"\n\x07\x63olumns\x18\x0f \x03(\x0b\x32\x11.dataframe.SeriesB\x0f\n\r_distinct_col\"@\n\x13\x44\x61taFrameIndexBlock\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0c\n\x04stop\x18\x02 \x01(\x03\x12\x0c\n\x04rows\x18\x03 \x01(\r\"\xa9\x01\n\x0e\x44\x61taFrameIndex\x12\x12\n\ntotal_rows\x18\x01 \x01(\r\x12\x1a\n\x12max_rows_per_block\x18\x02 \x01(\r\x12\x1a\n\x12max_rows_in_memory\x18\x05 \x01(\r\x12\r\n\x05start\x18\x03 \x01(\x03\x12\x0c\n\x04stop\x18\x04 \x01(\x03\x12.\n\x06\x62locks\x18\n \x03(\x0b\x32\x1e.dataframe.DataFrameIndexBlock*|\n\tFieldKind\x12\t\n\x05\x45mpty\x10\x00\x12\x0b\n\x05Int64\x10\x80\x80\x18\x12\x0e\n\x08\x44\x61teTime\x10\x81\x80\x18\x12\x0f\n\tDecimal64\x10\x82\x80\x18\x12\x0c\n\x06UInt64\x10\x83\x80\x18\x12\x0b\n\x05UInt8\x10\x81\x80 \x12\r\n\x07\x46loat64\x10\x80\x80\x38\x12\x0c\n\x06String\x10\x80\x80@b\x06proto3')

_FIELDKIND = DESCRIPTOR.enum_types_by_name['FieldKind']
FieldKind = enum_type_wrapper.EnumTypeWrapper(_FIELDKIND)
Empty = 0
Int64 = 393216
DateTime = 393217
Decimal64 = 393218
UInt64 = 393219
UInt8 = 524289
Float64 = 917504
String = 1048576


_SERIES = DESCRIPTOR.message_types_by_name['Series']
_DATAFRAME = DESCRIPTOR.message_types_by_name['DataFrame']
_DATAFRAMEINDEXBLOCK = DESCRIPTOR.message_types_by_name['DataFrameIndexBlock']
_DATAFRAMEINDEX = DESCRIPTOR.message_types_by_name['DataFrameIndex']
Series = _reflection.GeneratedProtocolMessageType('Series', (_message.Message,), {
  'DESCRIPTOR' : _SERIES,
  '__module__' : 'pymsd.proto.dataframe_pb2'
  # @@protoc_insertion_point(class_scope:dataframe.Series)
  })
_sym_db.RegisterMessage(Series)

DataFrame = _reflection.GeneratedProtocolMessageType('DataFrame', (_message.Message,), {
  'DESCRIPTOR' : _DATAFRAME,
  '__module__' : 'pymsd.proto.dataframe_pb2'
  # @@protoc_insertion_point(class_scope:dataframe.DataFrame)
  })
_sym_db.RegisterMessage(DataFrame)

DataFrameIndexBlock = _reflection.GeneratedProtocolMessageType('DataFrameIndexBlock', (_message.Message,), {
  'DESCRIPTOR' : _DATAFRAMEINDEXBLOCK,
  '__module__' : 'pymsd.proto.dataframe_pb2'
  # @@protoc_insertion_point(class_scope:dataframe.DataFrameIndexBlock)
  })
_sym_db.RegisterMessage(DataFrameIndexBlock)

DataFrameIndex = _reflection.GeneratedProtocolMessageType('DataFrameIndex', (_message.Message,), {
  'DESCRIPTOR' : _DATAFRAMEINDEX,
  '__module__' : 'pymsd.proto.dataframe_pb2'
  # @@protoc_insertion_point(class_scope:dataframe.DataFrameIndex)
  })
_sym_db.RegisterMessage(DataFrameIndex)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FIELDKIND._serialized_start=480
  _FIELDKIND._serialized_end=604
  _SERIES._serialized_start=42
  _SERIES._serialized_end=131
  _DATAFRAME._serialized_start=133
  _DATAFRAME._serialized_end=240
  _DATAFRAMEINDEXBLOCK._serialized_start=242
  _DATAFRAMEINDEXBLOCK._serialized_end=306
  _DATAFRAMEINDEX._serialized_start=309
  _DATAFRAMEINDEX._serialized_end=478
# @@protoc_insertion_point(module_scope)



import pyarrow as pa
import pyarrow.compute as pc
import pymsd.proto.dataframe_pb2 as msd
import numpy as np

def to_arrow_array(s : msd.Series) -> pa.Array:
    if s.dtype == msd.FieldKind.Float64:
        return pa.Array.from_buffers(pa.float64(), len(s.datas)/8, [None, pa.py_buffer(s.datas)])
    elif s.dtype == msd.FieldKind.Int64:
        return pa.Array.from_buffers(pa.int64(), len(s.datas)/8, [None, pa.py_buffer(s.datas)])
    elif s.dtype == msd.FieldKind.UInt64:
        return pa.Array.from_buffers(pa.uint64(), len(s.datas)/8, [None, pa.py_buffer(s.datas)])
    elif s.dtype == msd.FieldKind.DateTime:
        return pc.add(pa.Array.from_buffers(pa.int64(), len(s.datas)/8, [None, pa.py_buffer(s.datas)]), 8 * 3600 * 1_000_000_000).cast(pa.timestamp('ns'))
    elif s.dtype == msd.FieldKind.Decimal64:
        a = np.frombuffer(s.datas, '>i8')
        v = a >> 8
        d = 10**((a & 0xFF) >> 4)
        neg = np.where(a & 1 == 1, -1, 1)
        return pa.array(v * neg / d, type=pa.float64())
    elif s.dtype == msd.FieldKind.String:
        return pa.array(s.texts, type=pa.string())
    return None


from typing import List, Tuple
import numpy as np
import pymsd.proto.dataframe_pb2 as msd

def to_numpy_ndarray(s: msd.Series) -> np.ndarray:
    """
    convert msd.Series to numpy.ndarray
    """
    if s.dtype == msd.FieldKind.Float64:
        return np.frombuffer(s.datas, np.float64)
    if s.dtype == msd.FieldKind.Int64:
        return np.frombuffer(s.datas, np.int64)
    if s.dtype == msd.FieldKind.UInt64:
        return np.frombuffer(s.datas, np.uint64)
    if s.dtype == msd.FieldKind.DateTime:
        a = np.frombuffer(s.datas, 'datetime64[ns]')
        a = a + 8 * 3600 * 1_000_000_000
        return a
    if s.dtype == msd.FieldKind.Decimal64:
        a = np.frombuffer(s.datas, '>i8')
        v = a >> 8
        d = 10**((a & 0xFF) >> 4)
        neg = np.where(a & 1 == 1, -1.0, 1.0)
        return (v.astype(np.float64) * neg / d)
    if s.dtype == msd.FieldKind.String:
        return np.array(s.texts)
    return None

def to_numpy_list(df: msd.DataFrame) -> List[Tuple[str, np.ndarray]]:
    """
    convert msd.DataFrame to a list of named numpy.ndarray
    """
    data = []
    for c in df.columns:
        data.append((c.name, c))
    return data


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pymsd/proto/schema.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pymsd.proto import dataframe_pb2 as pymsd_dot_proto_dot_dataframe__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18pymsd/proto/schema.proto\x12\x06schema\x1a\x1bpymsd/proto/dataframe.proto\"\x86\x01\n\x08OpParams\x12\x16\n\tsrc_field\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nsrc_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rtrigger_field\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x0c\n\n_src_fieldB\r\n\x0b_src_schemaB\x10\n\x0e_trigger_field\"\xc9\x01\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05\x64type\x18\x02 \x01(\x0e\x32\x14.dataframe.FieldKind\x12\r\n\x05refer\x18\x03 \x01(\r\x12\x1b\n\x02op\x18\x04 \x01(\x0e\x32\x0f.schema.FieldOp\x12\r\n\x05paste\x18\x05 \x01(\x08\x12\x11\n\x04\x65xpr\x18\x06 \x01(\tH\x00\x88\x01\x01\x12(\n\top_params\x18\x07 \x01(\x0b\x32\x10.schema.OpParamsH\x01\x88\x01\x01\x42\x07\n\x05_exprB\x0c\n\n_op_params\"\xa0\x02\n\x06Schema\x12\x0e\n\x06pk_col\x18\x01 \x01(\x05\x12\x1d\n\x06\x66ields\x18\x02 \x03(\x0b\x32\r.schema.Field\x12\x1a\n\x12max_rows_per_block\x18\x03 \x01(\r\x12\x1a\n\x12max_rows_in_memory\x18\x04 \x01(\r\x12\x0e\n\x06\x63hains\x18\x05 \x03(\t\x12\x19\n\x0c\x64istinct_col\x18\x06 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03ttl\x18\x07 \x01(\rH\x01\x88\x01\x01\x12*\n\x06\x61\x64\x64ons\x18\x64 \x03(\x0b\x32\x1a.schema.Schema.AddonsEntry\x1a-\n\x0b\x41\x64\x64onsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\r_distinct_colB\x06\n\x04_ttl*\x87\x01\n\x07\x46ieldOp\x12\x08\n\x04Save\x10\x00\x12\r\n\tSaveFirst\x10\x01\x12\x0b\n\x07SaveMax\x10\x02\x12\x0b\n\x07SaveMin\x10\x03\x12\x07\n\x03Inc\x10\x04\x12\x0f\n\x0b\x44iffPrevios\x10\x05\x12\r\n\tDiffFirst\x10\x06\x12\t\n\x05\x43ount\x10\x07\x12\x07\n\x03\x41vg\x10\x08\x12\x0c\n\x08\x44istinct\x10\tb\x06proto3')

_FIELDOP = DESCRIPTOR.enum_types_by_name['FieldOp']
FieldOp = enum_type_wrapper.EnumTypeWrapper(_FIELDOP)
Save = 0
SaveFirst = 1
SaveMax = 2
SaveMin = 3
Inc = 4
DiffPrevios = 5
DiffFirst = 6
Count = 7
Avg = 8
Distinct = 9


_OPPARAMS = DESCRIPTOR.message_types_by_name['OpParams']
_FIELD = DESCRIPTOR.message_types_by_name['Field']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_SCHEMA_ADDONSENTRY = _SCHEMA.nested_types_by_name['AddonsEntry']
OpParams = _reflection.GeneratedProtocolMessageType('OpParams', (_message.Message,), {
  'DESCRIPTOR' : _OPPARAMS,
  '__module__' : 'pymsd.proto.schema_pb2'
  # @@protoc_insertion_point(class_scope:schema.OpParams)
  })
_sym_db.RegisterMessage(OpParams)

Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
  'DESCRIPTOR' : _FIELD,
  '__module__' : 'pymsd.proto.schema_pb2'
  # @@protoc_insertion_point(class_scope:schema.Field)
  })
_sym_db.RegisterMessage(Field)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {

  'AddonsEntry' : _reflection.GeneratedProtocolMessageType('AddonsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMA_ADDONSENTRY,
    '__module__' : 'pymsd.proto.schema_pb2'
    # @@protoc_insertion_point(class_scope:schema.Schema.AddonsEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'pymsd.proto.schema_pb2'
  # @@protoc_insertion_point(class_scope:schema.Schema)
  })
_sym_db.RegisterMessage(Schema)
_sym_db.RegisterMessage(Schema.AddonsEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCHEMA_ADDONSENTRY._options = None
  _SCHEMA_ADDONSENTRY._serialized_options = b'8\001'
  _FIELDOP._serialized_start=698
  _FIELDOP._serialized_end=833
  _OPPARAMS._serialized_start=66
  _OPPARAMS._serialized_end=200
  _FIELD._serialized_start=203
  _FIELD._serialized_end=404
  _SCHEMA._serialized_start=407
  _SCHEMA._serialized_end=695
  _SCHEMA_ADDONSENTRY._serialized_start=625
  _SCHEMA_ADDONSENTRY._serialized_end=670
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pymsd.proto import msd_pb2 as pymsd_dot_proto_dot_msd__pb2


class ApiV1Stub(object):
    """数据服务
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/msd.ApiV1/Get',
                request_serializer=pymsd_dot_proto_dot_msd__pb2.GetDataFrameRequest.SerializeToString,
                response_deserializer=pymsd_dot_proto_dot_msd__pb2.GetDataFrameResponse.FromString,
                )
        self.ListObject = channel.unary_unary(
                '/msd.ApiV1/ListObject',
                request_serializer=pymsd_dot_proto_dot_msd__pb2.ListObjectRequest.SerializeToString,
                response_deserializer=pymsd_dot_proto_dot_msd__pb2.ListObjectResponse.FromString,
                )
        self.Update = channel.stream_unary(
                '/msd.ApiV1/Update',
                request_serializer=pymsd_dot_proto_dot_msd__pb2.UpdateDataFrameRequest.SerializeToString,
                response_deserializer=pymsd_dot_proto_dot_msd__pb2.UpdateDataFrameResponse.FromString,
                )
        self.GetTable = channel.unary_unary(
                '/msd.ApiV1/GetTable',
                request_serializer=pymsd_dot_proto_dot_msd__pb2.GetTableRequest.SerializeToString,
                response_deserializer=pymsd_dot_proto_dot_msd__pb2.GetTableResponse.FromString,
                )
        self.UpdateMeta = channel.unary_unary(
                '/msd.ApiV1/UpdateMeta',
                request_serializer=pymsd_dot_proto_dot_msd__pb2.UpdateMetaRequest.SerializeToString,
                response_deserializer=pymsd_dot_proto_dot_msd__pb2.UpdateMetaResponse.FromString,
                )
        self.Forward = channel.unary_unary(
                '/msd.ApiV1/Forward',
                request_serializer=pymsd_dot_proto_dot_msd__pb2.ForwardRequest.SerializeToString,
                response_deserializer=pymsd_dot_proto_dot_msd__pb2.ForwardResponse.FromString,
                )
        self.SqlQuery = channel.unary_unary(
                '/msd.ApiV1/SqlQuery',
                request_serializer=pymsd_dot_proto_dot_msd__pb2.SqlRequest.SerializeToString,
                response_deserializer=pymsd_dot_proto_dot_msd__pb2.SqlResponse.FromString,
                )


class ApiV1Servicer(object):
    """数据服务
    """

    def Get(self, request, context):
        """获取数据请求
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListObject(self, request, context):
        """获取某个表中符合条件的 Object 信息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request_iterator, context):
        """更新数据请求
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTable(self, request, context):
        """获取表信息请求
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMeta(self, request, context):
        """更新元数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Forward(self, request, context):
        """转发相关的操作
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SqlQuery(self, request, context):
        """执行SQL
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ApiV1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=pymsd_dot_proto_dot_msd__pb2.GetDataFrameRequest.FromString,
                    response_serializer=pymsd_dot_proto_dot_msd__pb2.GetDataFrameResponse.SerializeToString,
            ),
            'ListObject': grpc.unary_unary_rpc_method_handler(
                    servicer.ListObject,
                    request_deserializer=pymsd_dot_proto_dot_msd__pb2.ListObjectRequest.FromString,
                    response_serializer=pymsd_dot_proto_dot_msd__pb2.ListObjectResponse.SerializeToString,
            ),
            'Update': grpc.stream_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=pymsd_dot_proto_dot_msd__pb2.UpdateDataFrameRequest.FromString,
                    response_serializer=pymsd_dot_proto_dot_msd__pb2.UpdateDataFrameResponse.SerializeToString,
            ),
            'GetTable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTable,
                    request_deserializer=pymsd_dot_proto_dot_msd__pb2.GetTableRequest.FromString,
                    response_serializer=pymsd_dot_proto_dot_msd__pb2.GetTableResponse.SerializeToString,
            ),
            'UpdateMeta': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMeta,
                    request_deserializer=pymsd_dot_proto_dot_msd__pb2.UpdateMetaRequest.FromString,
                    response_serializer=pymsd_dot_proto_dot_msd__pb2.UpdateMetaResponse.SerializeToString,
            ),
            'Forward': grpc.unary_unary_rpc_method_handler(
                    servicer.Forward,
                    request_deserializer=pymsd_dot_proto_dot_msd__pb2.ForwardRequest.FromString,
                    response_serializer=pymsd_dot_proto_dot_msd__pb2.ForwardResponse.SerializeToString,
            ),
            'SqlQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.SqlQuery,
                    request_deserializer=pymsd_dot_proto_dot_msd__pb2.SqlRequest.FromString,
                    response_serializer=pymsd_dot_proto_dot_msd__pb2.SqlResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'msd.ApiV1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ApiV1(object):
    """数据服务
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/msd.ApiV1/Get',
            pymsd_dot_proto_dot_msd__pb2.GetDataFrameRequest.SerializeToString,
            pymsd_dot_proto_dot_msd__pb2.GetDataFrameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/msd.ApiV1/ListObject',
            pymsd_dot_proto_dot_msd__pb2.ListObjectRequest.SerializeToString,
            pymsd_dot_proto_dot_msd__pb2.ListObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/msd.ApiV1/Update',
            pymsd_dot_proto_dot_msd__pb2.UpdateDataFrameRequest.SerializeToString,
            pymsd_dot_proto_dot_msd__pb2.UpdateDataFrameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/msd.ApiV1/GetTable',
            pymsd_dot_proto_dot_msd__pb2.GetTableRequest.SerializeToString,
            pymsd_dot_proto_dot_msd__pb2.GetTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMeta(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/msd.ApiV1/UpdateMeta',
            pymsd_dot_proto_dot_msd__pb2.UpdateMetaRequest.SerializeToString,
            pymsd_dot_proto_dot_msd__pb2.UpdateMetaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Forward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/msd.ApiV1/Forward',
            pymsd_dot_proto_dot_msd__pb2.ForwardRequest.SerializeToString,
            pymsd_dot_proto_dot_msd__pb2.ForwardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SqlQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/msd.ApiV1/SqlQuery',
            pymsd_dot_proto_dot_msd__pb2.SqlRequest.SerializeToString,
            pymsd_dot_proto_dot_msd__pb2.SqlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import pymsd
import grpc

_HOST = ''
_SYNC_CHANNEL: grpc.Channel = None
_ASYNC_CHANNEL: grpc.aio.Channel = None

def msd_query(host: str, sql: str) -> pymsd.DataFrame:

    global _HOST, _SYNC_CHANNEL
    if host != _HOST:
        if _SYNC_CHANNEL != None:
            _SYNC_CHANNEL.close()
        _HOST = host
        _SYNC_CHANNEL = grpc.insecure_channel(_HOST, None, 2)
    if _SYNC_CHANNEL is None:
        _SYNC_CHANNEL = grpc.insecure_channel(_HOST, None, 2)

    assert _SYNC_CHANNEL is not None

    stub = pymsd.ApiV1Stub(_SYNC_CHANNEL)
    req = pymsd.SqlRequest()
    req.sql = sql
    resp = stub.Get(req)
    return resp.values

async def msd_async_query(host: str, sql: str) -> pymsd.DataFrame:
    global _HOST, _ASYNC_CHANNEL
    if host != _HOST:
        if _SYNC_CHANNEL != None:
            _ASYNC_CHANNEL.close()
        _HOST = host
        _ASYNC_CHANNEL = grpc.aio.insecure_channel(_HOST, None, 2)
    if _ASYNC_CHANNEL is None:
        _ASYNC_CHANNEL = grpc.aio.insecure_channel(_HOST, None, 2)

    stub = pymsd.ApiV1Stub(_ASYNC_CHANNEL)
    req = pymsd.SqlRequest()
    req.sql = sql
    resp = await stub.Get(req)
    return resp.values



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pymsd', 'pymsd.proto']

package_data = \
{'': ['*']}

install_requires = \
['grpcio>=1,<2', 'numpy>=1,<2', 'protobuf>=3.20.1,<3.21.0']

setup_kwargs = {
    'name': 'pymsd',
    'version': '0.2.0',
    'description': 'the python sdk of msd-rs',
    'long_description': "the python sdk of [msd-rs](https://github.com/msd-rs/msd-rs)\n\nAlthough grpc can be used at any time, through [msd-proto](https://github.com/msd-rs/msd-proto) to generate client code to connect to the `msd` service, `msd-sdk-python` Simplifies the process and provides some handy helper functions to make calling easier\n\n尽管任何时候都可以使用 grpc, 通过 [msd-proto](https://github.com/msd-rs/msd-proto)  来生成连接 `msd` 服务的客户端代码，`msd-sdk-python` 简化了这个过程, 并提供了一些方便的辅助函数, 使得调用更加容易\n\n## 安装 (Install)\n\n```\npip install pymsd\n```\n\n## 使用 (Usage)\n\n### 快速上手 (QuickStart)\n\n```python\nimport pymsd\n\n# msd 服务的地址 | msd server address\nHOST='127.0.0.1:50051'\n\ndf = pymsd.msd_query(HOST, 'select * from kline1d.sh600000')\n# 或者使用异步模式 | or use aysnc mode\n# df = await pymsd.msd_query_async(HOST, 'select * from kline1d.sh600000')\n\n# to_pandas_dataframe 将结果集转换为 pandas.DataFrame, 需要 pandas 已经安装 | use `to_pandas_dataframe` covert result to pandas.DataFrame\n# to_polars_dataframe 将结果集转换为 polars.DataFrame, 需要 polars 已经安装 | use `to_polars_dataframe` covert result to polars.DataFrame\n# to_numpy_list 将结果集转换为[(名字, numpy.ndarray)], 需要 numpy 已经安装  | use `to_numpy_list` covert result to list of (name, numpy.ndarray) \ndf = pymsd.to_pandas_dataframe(df)\nprint(df)\n\n```\n\n### 自建连接\npymsd 提供了简单接口, 使用全局的服务连接, 也可以自建连接, 这时会有更好的控制\n\npymsd provides a simple interface, using the global service connection, you can also build your own connection, then there will be better control\n\n```python\nimport pymsd\nimport grpc\n\n# 创建 grpc 连接 | create grpc connection\nwith grpc.insecure_channel(_HOST) as channel:\n    stub = pymsd.DataFrameServiceStub(channel)\n\n    # 创建请求 | new request\n    req = pymsd.GetDataFrameRequest()\n    req.sql = sql\n\n    # 触发请求 | invoke request\n    resp = stub.Get(req)\n    # df 即是返回的结果集, 可以根据不同的需要, 将其转换成 pandas.DataFrame 等等 | df is the result, that can be convert to pandas.DataFrame etc.\n    df = resp.values\n```",
    'author': 'LiJia',
    'author_email': 'lijia.c@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/msd-rs/msd-sdk-python',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pymsd/proto/msd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pymsd.proto import dataframe_pb2 as pymsd_dot_proto_dot_dataframe__pb2
from pymsd.proto import schema_pb2 as pymsd_dot_proto_dot_schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15pymsd/proto/msd.proto\x12\x03msd\x1a\x1bpymsd/proto/dataframe.proto\x1a\x18pymsd/proto/schema.proto\"\xc9\x01\n\tGetParams\x12\x0b\n\x03obj\x18\x01 \x01(\t\x12\r\n\x05\x64kind\x18\x02 \x01(\t\x12\x0e\n\x06\x66ields\x18\x03 \x03(\t\x12\x12\n\nstart_date\x18\x04 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x05 \x01(\t\x12\x0e\n\x06offest\x18\x06 \x01(\x05\x12\r\n\x05limit\x18\x07 \x01(\x05\x12\x11\n\tascending\x18\x08 \x01(\x08\x12\x0b\n\x03ids\x18\t \x03(\t\x12\x0e\n\x06idname\x18\n \x01(\t\x12\x1b\n\x13\x61\x64\x64tional_where_ast\x18\x0b \x01(\t\"\xa7\x01\n\x13GetDataFrameRequest\x12\x1e\n\x06params\x18\x01 \x01(\x0b\x32\x0e.msd.GetParams\x12\x0b\n\x03sql\x18\x02 \x01(\t\x12\x34\n\x06\x61\x64\x64ons\x18\x64 \x03(\x0b\x32$.msd.GetDataFrameRequest.AddonsEntry\x1a-\n\x0b\x41\x64\x64onsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc0\x01\n\x14GetDataFrameResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0e\n\x06messge\x18\x02 \x01(\t\x12$\n\x06values\x18\x03 \x01(\x0b\x32\x14.dataframe.DataFrame\x12\x35\n\x06\x61\x64\x64ons\x18\x64 \x03(\x0b\x32%.msd.GetDataFrameResponse.AddonsEntry\x1a-\n\x0b\x41\x64\x64onsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x0fUpdateRowBinary\x12\x0c\n\x04rows\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"\xd0\x02\n\tCsvOption\x12\x0f\n\x07\x63sv_sep\x18\x01 \x01(\x05\x12\x13\n\x0bskip_head_n\x18\x02 \x01(\x05\x12\x13\n\x0bskip_tail_n\x18\x03 \x01(\x05\x12\x14\n\x0cskip_prefies\x18\x04 \x03(\t\x12\x1e\n\x16\x63sv_additation_row_sep\x18\x05 \x01(\x0c\x12\x1c\n\x14\x63sv_fixed_col_offset\x18\x06 \x03(\x05\x12\x17\n\x0f\x63sv_col_mapping\x18\x07 \x03(\x05\x12L\n\x19\x63sv_col_mapping_by_prefix\x18\x08 \x03(\x0b\x32).msd.CsvOption.CsvColMappingByPrefixEntry\x12\x0f\n\x07obj_col\x18\t \x01(\x05\x1a<\n\x1a\x43svColMappingByPrefixEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1c\n\x0cScriptOption\x12\x0c\n\x04name\x18\x01 \x01(\t\"w\n\x0fUpdateRowOption\x12$\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x14.msd.UpdateRowFormat\x12\x1b\n\x03\x63sv\x18\x02 \x01(\x0b\x32\x0e.msd.CsvOption\x12!\n\x06script\x18\x03 \x01(\x0b\x32\x11.msd.ScriptOption\"\xab\x01\n\x16UpdateDataFrameRequest\x12\x0b\n\x03obj\x18\x01 \x01(\t\x12\r\n\x05\x64kind\x18\x02 \x01(\t\x12\x0c\n\x04rows\x18\x03 \x01(\x0c\x12\x1d\n\x04mode\x18\x04 \x01(\x0e\x32\x0f.msd.UpdateMode\x12(\n\nrowsOption\x18\x05 \x01(\x0b\x32\x14.msd.UpdateRowOption\x12\x13\n\x06source\x18\x06 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_source\"M\n\x17UpdateDataFrameResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0e\n\x06messge\x18\x02 \x01(\t\x12\x14\n\x0cupdated_rows\x18\x03 \x01(\x05\"t\n\x11UpdateMetaRequest\x12\r\n\x05idkey\x18\x01 \x01(\t\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0c\n\x04json\x18\x03 \x01(\t\x12\r\n\x05jsonb\x18\x04 \x01(\x0c\x12\x16\n\tvalue_key\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_value_key\"2\n\x12UpdateMetaResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0e\n\x06messge\x18\x02 \x01(\t\"L\n\x06\x46ilter\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x1d\n\x04mode\x18\x02 \x01(\x0e\x32\x0f.msd.FilterMode\x12\x12\n\nignoreCase\x18\x03 \x01(\x08\"2\n\x0fGetTableRequest\x12\x1f\n\nnameFilter\x18\x01 \x01(\x0b\x32\x0b.msd.Filter\"\xa5\x01\n\x10GetTableResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0e\n\x06messge\x18\x02 \x01(\t\x12\x33\n\x07schemas\x18\x03 \x03(\x0b\x32\".msd.GetTableResponse.SchemasEntry\x1a>\n\x0cSchemasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.schema.Schema:\x02\x38\x01\"\\\n\x11ListObjectRequest\x12\r\n\x05\x64kind\x18\x01 \x01(\t\x12\x1e\n\tobjFilter\x18\x02 \x01(\x0b\x32\x0b.msd.Filter\x12\x10\n\x03sql\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x06\n\x04_sql\"\xb1\x02\n\x12ListObjectResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0e\n\x06messge\x18\x02 \x01(\t\x12\x35\n\x07objects\x18\x03 \x03(\x0b\x32$.msd.ListObjectResponse.ObjectsEntry\x12\x35\n\x07records\x18\x04 \x03(\x0b\x32$.msd.ListObjectResponse.RecordsEntry\x1aI\n\x0cObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.dataframe.DataFrameIndex:\x02\x38\x01\x1a\x44\n\x0cRecordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.dataframe.DataFrame:\x02\x38\x01\"\x82\x01\n\x0c\x42inlogRecord\x12\n\n\x02ts\x18\x01 \x01(\x03\x12&\n\x04Meta\x18\x05 \x01(\x0b\x32\x16.msd.UpdateMetaRequestH\x00\x12\x30\n\tDataFrame\x18\x06 \x01(\x0b\x32\x1b.msd.UpdateDataFrameRequestH\x00\x42\x0c\n\nanyRequest\"i\n\x0e\x46orwardRequest\x12!\n\toperation\x18\x01 \x01(\x0e\x32\x0e.msd.ForwardOp\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\x16\n\tstartDate\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_startDate\"\x1f\n\rForwardDetail\x12\x0e\n\x06lastTs\x18\x01 \x01(\x03\"\xaa\x01\n\x0f\x46orwardResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0e\n\x06messge\x18\x02 \x01(\t\x12\x34\n\x08\x66orwards\x18\n \x03(\x0b\x32\".msd.ForwardResponse.ForwardsEntry\x1a\x43\n\rForwardsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.msd.ForwardDetail:\x02\x38\x01\"3\n\nSqlRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x10\n\x03qid\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x06\n\x04_qid\"\xd6\x01\n\x0bSqlResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0e\n\x06messge\x18\x02 \x01(\t\x12\x10\n\x03qid\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04rows\x18\x04 \x01(\x05\x12$\n\x06values\x18\x05 \x01(\x0b\x32\x14.dataframe.DataFrame\x12,\n\x06\x61\x64\x64ons\x18\x64 \x03(\x0b\x32\x1c.msd.SqlResponse.AddonsEntry\x1a-\n\x0b\x41\x64\x64onsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04_qid*r\n\nUpdateMode\x12\n\n\x06Schema\x10\x00\x12\n\n\x06Import\x10\x01\x12\t\n\x05Paste\x10\x02\x12\x0e\n\nBulkSchema\x10\x03\x12\x0e\n\nBulkImport\x10\x04\x12\t\n\x05\x43hain\x10\x05\x12\n\n\x06Modify\x10\x06\x12\n\n\x06Script\x10\x07*G\n\x0fUpdateRowFormat\x12\x07\n\x03\x43sv\x10\x00\x12\n\n\x06\x42inary\x10\x01\x12\x0f\n\x0bJsonRecords\x10\x02\x12\x0e\n\nJsonValues\x10\x03*5\n\nFilterMode\x12\x08\n\x04\x46ull\x10\x00\x12\x08\n\x04Part\x10\x01\x12\x08\n\x04Glob\x10\x02\x12\t\n\x05Regex\x10\x03*@\n\tForwardOp\x12\x10\n\x0cStartForward\x10\x00\x12\x0f\n\x0bStopForward\x10\x01\x12\x10\n\x0cListForwards\x10\x02\x32\xb4\x03\n\x05\x41piV1\x12<\n\x03Get\x12\x18.msd.GetDataFrameRequest\x1a\x19.msd.GetDataFrameResponse\"\x00\x12?\n\nListObject\x12\x16.msd.ListObjectRequest\x1a\x17.msd.ListObjectResponse\"\x00\x12G\n\x06Update\x12\x1b.msd.UpdateDataFrameRequest\x1a\x1c.msd.UpdateDataFrameResponse\"\x00(\x01\x12\x39\n\x08GetTable\x12\x14.msd.GetTableRequest\x1a\x15.msd.GetTableResponse\"\x00\x12?\n\nUpdateMeta\x12\x16.msd.UpdateMetaRequest\x1a\x17.msd.UpdateMetaResponse\"\x00\x12\x36\n\x07\x46orward\x12\x13.msd.ForwardRequest\x1a\x14.msd.ForwardResponse\"\x00\x12/\n\x08SqlQuery\x12\x0f.msd.SqlRequest\x1a\x10.msd.SqlResponse\"\x00\x62\x06proto3')

_UPDATEMODE = DESCRIPTOR.enum_types_by_name['UpdateMode']
UpdateMode = enum_type_wrapper.EnumTypeWrapper(_UPDATEMODE)
_UPDATEROWFORMAT = DESCRIPTOR.enum_types_by_name['UpdateRowFormat']
UpdateRowFormat = enum_type_wrapper.EnumTypeWrapper(_UPDATEROWFORMAT)
_FILTERMODE = DESCRIPTOR.enum_types_by_name['FilterMode']
FilterMode = enum_type_wrapper.EnumTypeWrapper(_FILTERMODE)
_FORWARDOP = DESCRIPTOR.enum_types_by_name['ForwardOp']
ForwardOp = enum_type_wrapper.EnumTypeWrapper(_FORWARDOP)
Schema = 0
Import = 1
Paste = 2
BulkSchema = 3
BulkImport = 4
Chain = 5
Modify = 6
Script = 7
Csv = 0
Binary = 1
JsonRecords = 2
JsonValues = 3
Full = 0
Part = 1
Glob = 2
Regex = 3
StartForward = 0
StopForward = 1
ListForwards = 2


_GETPARAMS = DESCRIPTOR.message_types_by_name['GetParams']
_GETDATAFRAMEREQUEST = DESCRIPTOR.message_types_by_name['GetDataFrameRequest']
_GETDATAFRAMEREQUEST_ADDONSENTRY = _GETDATAFRAMEREQUEST.nested_types_by_name['AddonsEntry']
_GETDATAFRAMERESPONSE = DESCRIPTOR.message_types_by_name['GetDataFrameResponse']
_GETDATAFRAMERESPONSE_ADDONSENTRY = _GETDATAFRAMERESPONSE.nested_types_by_name['AddonsEntry']
_UPDATEROWBINARY = DESCRIPTOR.message_types_by_name['UpdateRowBinary']
_CSVOPTION = DESCRIPTOR.message_types_by_name['CsvOption']
_CSVOPTION_CSVCOLMAPPINGBYPREFIXENTRY = _CSVOPTION.nested_types_by_name['CsvColMappingByPrefixEntry']
_SCRIPTOPTION = DESCRIPTOR.message_types_by_name['ScriptOption']
_UPDATEROWOPTION = DESCRIPTOR.message_types_by_name['UpdateRowOption']
_UPDATEDATAFRAMEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataFrameRequest']
_UPDATEDATAFRAMERESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataFrameResponse']
_UPDATEMETAREQUEST = DESCRIPTOR.message_types_by_name['UpdateMetaRequest']
_UPDATEMETARESPONSE = DESCRIPTOR.message_types_by_name['UpdateMetaResponse']
_FILTER = DESCRIPTOR.message_types_by_name['Filter']
_GETTABLEREQUEST = DESCRIPTOR.message_types_by_name['GetTableRequest']
_GETTABLERESPONSE = DESCRIPTOR.message_types_by_name['GetTableResponse']
_GETTABLERESPONSE_SCHEMASENTRY = _GETTABLERESPONSE.nested_types_by_name['SchemasEntry']
_LISTOBJECTREQUEST = DESCRIPTOR.message_types_by_name['ListObjectRequest']
_LISTOBJECTRESPONSE = DESCRIPTOR.message_types_by_name['ListObjectResponse']
_LISTOBJECTRESPONSE_OBJECTSENTRY = _LISTOBJECTRESPONSE.nested_types_by_name['ObjectsEntry']
_LISTOBJECTRESPONSE_RECORDSENTRY = _LISTOBJECTRESPONSE.nested_types_by_name['RecordsEntry']
_BINLOGRECORD = DESCRIPTOR.message_types_by_name['BinlogRecord']
_FORWARDREQUEST = DESCRIPTOR.message_types_by_name['ForwardRequest']
_FORWARDDETAIL = DESCRIPTOR.message_types_by_name['ForwardDetail']
_FORWARDRESPONSE = DESCRIPTOR.message_types_by_name['ForwardResponse']
_FORWARDRESPONSE_FORWARDSENTRY = _FORWARDRESPONSE.nested_types_by_name['ForwardsEntry']
_SQLREQUEST = DESCRIPTOR.message_types_by_name['SqlRequest']
_SQLRESPONSE = DESCRIPTOR.message_types_by_name['SqlResponse']
_SQLRESPONSE_ADDONSENTRY = _SQLRESPONSE.nested_types_by_name['AddonsEntry']
GetParams = _reflection.GeneratedProtocolMessageType('GetParams', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMS,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.GetParams)
  })
_sym_db.RegisterMessage(GetParams)

GetDataFrameRequest = _reflection.GeneratedProtocolMessageType('GetDataFrameRequest', (_message.Message,), {

  'AddonsEntry' : _reflection.GeneratedProtocolMessageType('AddonsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETDATAFRAMEREQUEST_ADDONSENTRY,
    '__module__' : 'pymsd.proto.msd_pb2'
    # @@protoc_insertion_point(class_scope:msd.GetDataFrameRequest.AddonsEntry)
    })
  ,
  'DESCRIPTOR' : _GETDATAFRAMEREQUEST,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.GetDataFrameRequest)
  })
_sym_db.RegisterMessage(GetDataFrameRequest)
_sym_db.RegisterMessage(GetDataFrameRequest.AddonsEntry)

GetDataFrameResponse = _reflection.GeneratedProtocolMessageType('GetDataFrameResponse', (_message.Message,), {

  'AddonsEntry' : _reflection.GeneratedProtocolMessageType('AddonsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETDATAFRAMERESPONSE_ADDONSENTRY,
    '__module__' : 'pymsd.proto.msd_pb2'
    # @@protoc_insertion_point(class_scope:msd.GetDataFrameResponse.AddonsEntry)
    })
  ,
  'DESCRIPTOR' : _GETDATAFRAMERESPONSE,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.GetDataFrameResponse)
  })
_sym_db.RegisterMessage(GetDataFrameResponse)
_sym_db.RegisterMessage(GetDataFrameResponse.AddonsEntry)

UpdateRowBinary = _reflection.GeneratedProtocolMessageType('UpdateRowBinary', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROWBINARY,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.UpdateRowBinary)
  })
_sym_db.RegisterMessage(UpdateRowBinary)

CsvOption = _reflection.GeneratedProtocolMessageType('CsvOption', (_message.Message,), {

  'CsvColMappingByPrefixEntry' : _reflection.GeneratedProtocolMessageType('CsvColMappingByPrefixEntry', (_message.Message,), {
    'DESCRIPTOR' : _CSVOPTION_CSVCOLMAPPINGBYPREFIXENTRY,
    '__module__' : 'pymsd.proto.msd_pb2'
    # @@protoc_insertion_point(class_scope:msd.CsvOption.CsvColMappingByPrefixEntry)
    })
  ,
  'DESCRIPTOR' : _CSVOPTION,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.CsvOption)
  })
_sym_db.RegisterMessage(CsvOption)
_sym_db.RegisterMessage(CsvOption.CsvColMappingByPrefixEntry)

ScriptOption = _reflection.GeneratedProtocolMessageType('ScriptOption', (_message.Message,), {
  'DESCRIPTOR' : _SCRIPTOPTION,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.ScriptOption)
  })
_sym_db.RegisterMessage(ScriptOption)

UpdateRowOption = _reflection.GeneratedProtocolMessageType('UpdateRowOption', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROWOPTION,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.UpdateRowOption)
  })
_sym_db.RegisterMessage(UpdateRowOption)

UpdateDataFrameRequest = _reflection.GeneratedProtocolMessageType('UpdateDataFrameRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAFRAMEREQUEST,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.UpdateDataFrameRequest)
  })
_sym_db.RegisterMessage(UpdateDataFrameRequest)

UpdateDataFrameResponse = _reflection.GeneratedProtocolMessageType('UpdateDataFrameResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAFRAMERESPONSE,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.UpdateDataFrameResponse)
  })
_sym_db.RegisterMessage(UpdateDataFrameResponse)

UpdateMetaRequest = _reflection.GeneratedProtocolMessageType('UpdateMetaRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMETAREQUEST,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.UpdateMetaRequest)
  })
_sym_db.RegisterMessage(UpdateMetaRequest)

UpdateMetaResponse = _reflection.GeneratedProtocolMessageType('UpdateMetaResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMETARESPONSE,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.UpdateMetaResponse)
  })
_sym_db.RegisterMessage(UpdateMetaResponse)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.Filter)
  })
_sym_db.RegisterMessage(Filter)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {

  'SchemasEntry' : _reflection.GeneratedProtocolMessageType('SchemasEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETTABLERESPONSE_SCHEMASENTRY,
    '__module__' : 'pymsd.proto.msd_pb2'
    # @@protoc_insertion_point(class_scope:msd.GetTableResponse.SchemasEntry)
    })
  ,
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)
_sym_db.RegisterMessage(GetTableResponse.SchemasEntry)

ListObjectRequest = _reflection.GeneratedProtocolMessageType('ListObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTREQUEST,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.ListObjectRequest)
  })
_sym_db.RegisterMessage(ListObjectRequest)

ListObjectResponse = _reflection.GeneratedProtocolMessageType('ListObjectResponse', (_message.Message,), {

  'ObjectsEntry' : _reflection.GeneratedProtocolMessageType('ObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTOBJECTRESPONSE_OBJECTSENTRY,
    '__module__' : 'pymsd.proto.msd_pb2'
    # @@protoc_insertion_point(class_scope:msd.ListObjectResponse.ObjectsEntry)
    })
  ,

  'RecordsEntry' : _reflection.GeneratedProtocolMessageType('RecordsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTOBJECTRESPONSE_RECORDSENTRY,
    '__module__' : 'pymsd.proto.msd_pb2'
    # @@protoc_insertion_point(class_scope:msd.ListObjectResponse.RecordsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTOBJECTRESPONSE,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.ListObjectResponse)
  })
_sym_db.RegisterMessage(ListObjectResponse)
_sym_db.RegisterMessage(ListObjectResponse.ObjectsEntry)
_sym_db.RegisterMessage(ListObjectResponse.RecordsEntry)

BinlogRecord = _reflection.GeneratedProtocolMessageType('BinlogRecord', (_message.Message,), {
  'DESCRIPTOR' : _BINLOGRECORD,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.BinlogRecord)
  })
_sym_db.RegisterMessage(BinlogRecord)

ForwardRequest = _reflection.GeneratedProtocolMessageType('ForwardRequest', (_message.Message,), {
  'DESCRIPTOR' : _FORWARDREQUEST,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.ForwardRequest)
  })
_sym_db.RegisterMessage(ForwardRequest)

ForwardDetail = _reflection.GeneratedProtocolMessageType('ForwardDetail', (_message.Message,), {
  'DESCRIPTOR' : _FORWARDDETAIL,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.ForwardDetail)
  })
_sym_db.RegisterMessage(ForwardDetail)

ForwardResponse = _reflection.GeneratedProtocolMessageType('ForwardResponse', (_message.Message,), {

  'ForwardsEntry' : _reflection.GeneratedProtocolMessageType('ForwardsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FORWARDRESPONSE_FORWARDSENTRY,
    '__module__' : 'pymsd.proto.msd_pb2'
    # @@protoc_insertion_point(class_scope:msd.ForwardResponse.ForwardsEntry)
    })
  ,
  'DESCRIPTOR' : _FORWARDRESPONSE,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.ForwardResponse)
  })
_sym_db.RegisterMessage(ForwardResponse)
_sym_db.RegisterMessage(ForwardResponse.ForwardsEntry)

SqlRequest = _reflection.GeneratedProtocolMessageType('SqlRequest', (_message.Message,), {
  'DESCRIPTOR' : _SQLREQUEST,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.SqlRequest)
  })
_sym_db.RegisterMessage(SqlRequest)

SqlResponse = _reflection.GeneratedProtocolMessageType('SqlResponse', (_message.Message,), {

  'AddonsEntry' : _reflection.GeneratedProtocolMessageType('AddonsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SQLRESPONSE_ADDONSENTRY,
    '__module__' : 'pymsd.proto.msd_pb2'
    # @@protoc_insertion_point(class_scope:msd.SqlResponse.AddonsEntry)
    })
  ,
  'DESCRIPTOR' : _SQLRESPONSE,
  '__module__' : 'pymsd.proto.msd_pb2'
  # @@protoc_insertion_point(class_scope:msd.SqlResponse)
  })
_sym_db.RegisterMessage(SqlResponse)
_sym_db.RegisterMessage(SqlResponse.AddonsEntry)

_APIV1 = DESCRIPTOR.services_by_name['ApiV1']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETDATAFRAMEREQUEST_ADDONSENTRY._options = None
  _GETDATAFRAMEREQUEST_ADDONSENTRY._serialized_options = b'8\001'
  _GETDATAFRAMERESPONSE_ADDONSENTRY._options = None
  _GETDATAFRAMERESPONSE_ADDONSENTRY._serialized_options = b'8\001'
  _CSVOPTION_CSVCOLMAPPINGBYPREFIXENTRY._options = None
  _CSVOPTION_CSVCOLMAPPINGBYPREFIXENTRY._serialized_options = b'8\001'
  _GETTABLERESPONSE_SCHEMASENTRY._options = None
  _GETTABLERESPONSE_SCHEMASENTRY._serialized_options = b'8\001'
  _LISTOBJECTRESPONSE_OBJECTSENTRY._options = None
  _LISTOBJECTRESPONSE_OBJECTSENTRY._serialized_options = b'8\001'
  _LISTOBJECTRESPONSE_RECORDSENTRY._options = None
  _LISTOBJECTRESPONSE_RECORDSENTRY._serialized_options = b'8\001'
  _FORWARDRESPONSE_FORWARDSENTRY._options = None
  _FORWARDRESPONSE_FORWARDSENTRY._serialized_options = b'8\001'
  _SQLRESPONSE_ADDONSENTRY._options = None
  _SQLRESPONSE_ADDONSENTRY._serialized_options = b'8\001'
  _UPDATEMODE._serialized_start=3046
  _UPDATEMODE._serialized_end=3160
  _UPDATEROWFORMAT._serialized_start=3162
  _UPDATEROWFORMAT._serialized_end=3233
  _FILTERMODE._serialized_start=3235
  _FILTERMODE._serialized_end=3288
  _FORWARDOP._serialized_start=3290
  _FORWARDOP._serialized_end=3354
  _GETPARAMS._serialized_start=86
  _GETPARAMS._serialized_end=287
  _GETDATAFRAMEREQUEST._serialized_start=290
  _GETDATAFRAMEREQUEST._serialized_end=457
  _GETDATAFRAMEREQUEST_ADDONSENTRY._serialized_start=412
  _GETDATAFRAMEREQUEST_ADDONSENTRY._serialized_end=457
  _GETDATAFRAMERESPONSE._serialized_start=460
  _GETDATAFRAMERESPONSE._serialized_end=652
  _GETDATAFRAMERESPONSE_ADDONSENTRY._serialized_start=412
  _GETDATAFRAMERESPONSE_ADDONSENTRY._serialized_end=457
  _UPDATEROWBINARY._serialized_start=654
  _UPDATEROWBINARY._serialized_end=715
  _CSVOPTION._serialized_start=718
  _CSVOPTION._serialized_end=1054
  _CSVOPTION_CSVCOLMAPPINGBYPREFIXENTRY._serialized_start=994
  _CSVOPTION_CSVCOLMAPPINGBYPREFIXENTRY._serialized_end=1054
  _SCRIPTOPTION._serialized_start=1056
  _SCRIPTOPTION._serialized_end=1084
  _UPDATEROWOPTION._serialized_start=1086
  _UPDATEROWOPTION._serialized_end=1205
  _UPDATEDATAFRAMEREQUEST._serialized_start=1208
  _UPDATEDATAFRAMEREQUEST._serialized_end=1379
  _UPDATEDATAFRAMERESPONSE._serialized_start=1381
  _UPDATEDATAFRAMERESPONSE._serialized_end=1458
  _UPDATEMETAREQUEST._serialized_start=1460
  _UPDATEMETAREQUEST._serialized_end=1576
  _UPDATEMETARESPONSE._serialized_start=1578
  _UPDATEMETARESPONSE._serialized_end=1628
  _FILTER._serialized_start=1630
  _FILTER._serialized_end=1706
  _GETTABLEREQUEST._serialized_start=1708
  _GETTABLEREQUEST._serialized_end=1758
  _GETTABLERESPONSE._serialized_start=1761
  _GETTABLERESPONSE._serialized_end=1926
  _GETTABLERESPONSE_SCHEMASENTRY._serialized_start=1864
  _GETTABLERESPONSE_SCHEMASENTRY._serialized_end=1926
  _LISTOBJECTREQUEST._serialized_start=1928
  _LISTOBJECTREQUEST._serialized_end=2020
  _LISTOBJECTRESPONSE._serialized_start=2023
  _LISTOBJECTRESPONSE._serialized_end=2328
  _LISTOBJECTRESPONSE_OBJECTSENTRY._serialized_start=2185
  _LISTOBJECTRESPONSE_OBJECTSENTRY._serialized_end=2258
  _LISTOBJECTRESPONSE_RECORDSENTRY._serialized_start=2260
  _LISTOBJECTRESPONSE_RECORDSENTRY._serialized_end=2328
  _BINLOGRECORD._serialized_start=2331
  _BINLOGRECORD._serialized_end=2461
  _FORWARDREQUEST._serialized_start=2463
  _FORWARDREQUEST._serialized_end=2568
  _FORWARDDETAIL._serialized_start=2570
  _FORWARDDETAIL._serialized_end=2601
  _FORWARDRESPONSE._serialized_start=2604
  _FORWARDRESPONSE._serialized_end=2774
  _FORWARDRESPONSE_FORWARDSENTRY._serialized_start=2707
  _FORWARDRESPONSE_FORWARDSENTRY._serialized_end=2774
  _SQLREQUEST._serialized_start=2776
  _SQLREQUEST._serialized_end=2827
  _SQLRESPONSE._serialized_start=2830
  _SQLRESPONSE._serialized_end=3044
  _SQLRESPONSE_ADDONSENTRY._serialized_start=412
  _SQLRESPONSE_ADDONSENTRY._serialized_end=457
  _APIV1._serialized_start=3357
  _APIV1._serialized_end=3793
# @@protoc_insertion_point(module_scope)
